@@ -102,7 +102,7 @@ class ThrottlingDeferred(_ConcurrencyPrimitive):
         # has completed.
         self.points = self.calls
         # If we don't check for this we will overflow the queue on long running calls.
-        if self._lastReset and self._lastReset.called:
+        if self._lastReset is None or self._lastReset.called:
             self._lastReset = self._sem.run(self.release)
 
     def acquire(self, priority=False):
